@@ -52,9 +52,12 @@ class Feed(BaseModel):
         Gets the feed and creates new entries for new content.
         """
         logging.info("fetching feed: %s", self.url)
-        feed = feedparser.parse(self.url)
+        try:
+            feed = feedparser.parse(self.url)
+        except Exception as e:
+            logging.error("unable to fetch feed %s: %s", self.url, e)
         for e in feed.entries:
-            # TODO: look up with url only, because there may be 
+            # note: look up with url only, because there may be 
             # overlap bewteen feeds, especially when a large newspaper
             # has multiple feeds
             entry, created = Entry.get_or_create(url=e.link)
@@ -65,7 +68,6 @@ class Feed(BaseModel):
                 FeedEntry.create(entry=entry, feed=self)
                 logging.debug("found entry from another feed: %s", e.link)
 
-
 class Entry(BaseModel):
     url = CharField()
     created = DateTimeField(default=datetime.utcnow)
